@@ -13,7 +13,7 @@ from fds.services.types import InnerService
 from fds.services.git_service import GitService
 from fds.services.pretty_print import PrettyPrint
 from fds.utils import execute_command, rerun_in_new_shell_and_exit
-from .__init__ import __version__
+from .version import __version__
 
 
 class HooksRunner(object):
@@ -53,14 +53,14 @@ class HooksRunner(object):
             {
                 'type': 'confirm',
                 'message': 'Should we install dvc [https://dvc.org/] for you right now?\n' +
-                           '  Will install using `pip3 install dvc<3`',
+                           '  Will install using `pip3 install dvc==2.3.0`',
                 'name': 'install',
                 'default': False,
             },
         ]
         answers = PyInquirer.prompt(questions)
         if answers["install"]:
-            execute_command(["pip3 install 'dvc<3'"], shell=True, capture_output=False)
+            execute_command(["pip3 install 'dvc==2.3.0'"], shell=True, capture_output=False)
             ret_code = 0
         else:
             # Provide instructions
